==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d7/d3c/town_8h.js <==
var town_8h =
[
    [ "BuildingCounts", "dc/d60/structBuildingCounts.html", "dc/d60/structBuildingCounts" ],
    [ "TownCache", "db/d59/structTownCache.html", "db/d59/structTownCache" ],
    [ "Town", "d5/d2b/structTown.html", "d5/d2b/structTown" ],
    [ "FOR_ALL_TOWNS", "d7/d3c/town_8h.html#a333b6bc05a88a0a4750b9bfad978f46e", null ],
    [ "FOR_ALL_TOWNS_FROM", "d7/d3c/town_8h.html#a8e40c9bd0ddbf49efa2114afcfd3687c", null ],
    [ "AcceptanceMatrix", "d7/d3c/town_8h.html#ac4109d6c4b69d8e5d146395051a21467", null ],
    [ "TownPool", "d7/d3c/town_8h.html#a68179fc589018dd681c201465e81500f", null ],
    [ "TownActions", "d7/d3c/town_8h.html#a72b2e096f98a5a7ef720ef025f093e9f", [
      [ "TACT_NONE", "d7/d3c/town_8h.html#a72b2e096f98a5a7ef720ef025f093e9fad99b49a57498197befc36f4db8f86945", null ],
      [ "TACT_ADVERTISE_SMALL", "d7/d3c/town_8h.html#a72b2e096f98a5a7ef720ef025f093e9faff23739b2d068acce1a51ba397f6622d", null ],
      [ "TACT_ADVERTISE_MEDIUM", "d7/d3c/town_8h.html#a72b2e096f98a5a7ef720ef025f093e9fa20eab3954941c49fa89e346844fb359e", null ],
      [ "TACT_ADVERTISE_LARGE", "d7/d3c/town_8h.html#a72b2e096f98a5a7ef720ef025f093e9fafe2af793002e2bb9f47352824da2b3d6", null ],
      [ "TACT_ROAD_REBUILD", "d7/d3c/town_8h.html#a72b2e096f98a5a7ef720ef025f093e9fa1f7f29ec702d5622749aa0ad53b5e295", null ],
      [ "TACT_BUILD_STATUE", "d7/d3c/town_8h.html#a72b2e096f98a5a7ef720ef025f093e9fa0ba321c8f614ecc09a5e8be1e8f0ebe8", null ],
      [ "TACT_FUND_BUILDINGS", "d7/d3c/town_8h.html#a72b2e096f98a5a7ef720ef025f093e9faba3c259c45bbf8827520c049576ead8b", null ],
      [ "TACT_BUY_RIGHTS", "d7/d3c/town_8h.html#a72b2e096f98a5a7ef720ef025f093e9fa2b4e821fc7092f84195406d5d59a227b", null ],
      [ "TACT_BRIBE", "d7/d3c/town_8h.html#a72b2e096f98a5a7ef720ef025f093e9fa3d934b23e4970d085ad47873bbb2764e", null ],
      [ "TACT_COUNT", "d7/d3c/town_8h.html#a72b2e096f98a5a7ef720ef025f093e9fa591e8d8768b41649d6bb26330a2261fd", null ],
      [ "TACT_ADVERTISE", "d7/d3c/town_8h.html#a72b2e096f98a5a7ef720ef025f093e9fa4ad3cf8c16edcdcb4a50d2c9c052f6c2", null ],
      [ "TACT_CONSTRUCTION", "d7/d3c/town_8h.html#a72b2e096f98a5a7ef720ef025f093e9fa1505349147574404c149fd07dc46df42", null ],
      [ "TACT_FUNDS", "d7/d3c/town_8h.html#a72b2e096f98a5a7ef720ef025f093e9facfddb438ffb38e392c0916b7c1c4dfae", null ],
      [ "TACT_ALL", "d7/d3c/town_8h.html#a72b2e096f98a5a7ef720ef025f093e9fa856a9252cb1de2e44619f5a45acb83db", null ]
    ] ],
    [ "TownFlags", "d7/d3c/town_8h.html#a3d1adcf1c18f19d00974fba3ba41c125", [
      [ "TOWN_IS_GROWING", "d7/d3c/town_8h.html#a3d1adcf1c18f19d00974fba3ba41c125a4cf8a495341d0d8a7011eac51a2fb978", null ],
      [ "TOWN_HAS_CHURCH", "d7/d3c/town_8h.html#a3d1adcf1c18f19d00974fba3ba41c125a1e3de1cbe2e682c8d0c4aa63a0c4980c", null ],
      [ "TOWN_HAS_STADIUM", "d7/d3c/town_8h.html#a3d1adcf1c18f19d00974fba3ba41c125a4b90abb9bbbe668d1b0e97ca3fa019f7", null ],
      [ "TOWN_CUSTOM_GROWTH", "d7/d3c/town_8h.html#a3d1adcf1c18f19d00974fba3ba41c125ad3f6b5cc75026c0848a0f63a14c24ee1", null ]
    ] ],
    [ "TownRatingCheckType", "d7/d3c/town_8h.html#a4c86370b4817abedcf0491b80262eb5a", [
      [ "ROAD_REMOVE", "d7/d3c/town_8h.html#a4c86370b4817abedcf0491b80262eb5aa1a4afb382e9f6142a316e3310957e7c3", null ],
      [ "TUNNELBRIDGE_REMOVE", "d7/d3c/town_8h.html#a4c86370b4817abedcf0491b80262eb5aaebb872165d784ea990c873a8f868412a", null ],
      [ "TOWN_RATING_CHECK_TYPE_COUNT", "d7/d3c/town_8h.html#a4c86370b4817abedcf0491b80262eb5aafa1361ad0ad1bd7300e75fec950aaf92", null ]
    ] ],
    [ "CalcClosestTownFromTile", "d7/d3c/town_8h.html#a9e7b91f9ad0689788a4ca95af39eb210", null ],
    [ "ChangeTownRating", "d7/d3c/town_8h.html#aa401b952a00674845ccb4273050928da", null ],
    [ "CheckforTownRating", "d7/d3c/town_8h.html#acebc77005f110c964d3d5850edb7a296", null ],
    [ "CheckIfAuthorityAllowsNewStation", "d7/d3c/town_8h.html#aca6c6d9e664f92c2c407015d2e2f7797", null ],
    [ "ClearTownHouse", "d7/d3c/town_8h.html#a27b0cd4feaa3b85e5b9bc1ceea1eacc9", null ],
    [ "ClosestTownFromTile", "d7/d3c/town_8h.html#aefa41cb32a5c5faf518e67d065e7e0aa", null ],
    [ "ExpandTown", "d7/d3c/town_8h.html#adff01d611111448e7d7d2f2eaec194f4", null ],
    [ "FindFirstCargoWithTownEffect", "d7/d3c/town_8h.html#aab72028c5d4b66eb49342c7e2b7b7c20", null ],
    [ "GenerateTowns", "d7/d3c/town_8h.html#ac91d59f170b938ec1b4cbbf3b8618f64", null ],
    [ "GetHouseNorthPart", "d7/d3c/town_8h.html#a208081907f1ac4046976e0fc57541cee", null ],
    [ "GetMaskOfTownActions", "d7/d3c/town_8h.html#a18def58b8accdaf835f958d548f8e164", null ],
    [ "GetTownRadiusGroup", "d7/d3c/town_8h.html#a10f6e3691ee7cc2f6a363f25d5b88024", null ],
    [ "GetWorldPopulation", "d7/d3c/town_8h.html#a27638ea8500cdb01e0d227e41ec59276", null ],
    [ "MakeDefaultName", "d7/d3c/town_8h.html#af900090912159e59f37b1c5efc2db226", null ],
    [ "ResetHouses", "d7/d3c/town_8h.html#a147c34083fcb9fb68acf342403e812c1", null ],
    [ "SetTownRatingTestMode", "d7/d3c/town_8h.html#ad64a5b99bb3a7b288704ab1b786ddf7e", null ],
    [ "ShowTownViewWindow", "d7/d3c/town_8h.html#a7fa05100148d062259fe641fdfbdd5a8", null ],
    [ "TownTicksToGameTicks", "d7/d3c/town_8h.html#a4b26e8253fd291e3a3636d26cdd8b51f", null ],
    [ "UpdateAllTownVirtCoords", "d7/d3c/town_8h.html#afccb9292782ea4d9a12573d4a45bdbea", null ],
    [ "UpdateTownCargoBitmap", "d7/d3c/town_8h.html#a9887d2729c1eb98b21059cd41fc61692", null ],
    [ "UpdateTownCargoes", "d7/d3c/town_8h.html#a08894b4c86852fc4c3b64b9892f4cd8c", null ],
    [ "UpdateTownCargoTotal", "d7/d3c/town_8h.html#a7ea0c1c81ca673976cccf561fd308159", null ],
    [ "UpdateTownMaxPass", "d7/d3c/town_8h.html#a7cd754f6784c6cb4338a139ef7acbdd2", null ],
    [ "UpdateTownRadius", "d7/d3c/town_8h.html#add12c33889bf9775a848384d3a9dd32d", null ],
    [ "_new_town_id", "d7/d3c/town_8h.html#a03764eb9bec65bdcd9a41de5d514323b", null ],
    [ "_town_action_costs", "d7/d3c/town_8h.html#a0f5db20740045b5f48bfaf0a3ca6c565", null ],
    [ "_town_cargoes_accepted", "d7/d3c/town_8h.html#a402089ca5c177476d6e75b7e87448dda", null ],
    [ "_town_pool", "d7/d3c/town_8h.html#a03bf9fd09ecb05692b990c7333e104d7", null ],
    [ "CUSTOM_TOWN_MAX_NUMBER", "d7/d3c/town_8h.html#a6e12dc158c20578e0b2a57344c8c90e4", null ],
    [ "CUSTOM_TOWN_NUMBER_DIFFICULTY", "d7/d3c/town_8h.html#aa1d17bb2c2d2e1cff4ce12def54e73d0", null ],
    [ "INVALID_TOWN", "d7/d3c/town_8h.html#ae581e6ec9bc5fd49cc42c1851a47ce9c", null ],
    [ "MAX_TOWN_GROWTH_TICKS", "d7/d3c/town_8h.html#a628187fb72c38bc95d4a95bb1e0676a4", null ],
    [ "TOWN_GROWTH_DESERT", "d7/d3c/town_8h.html#a39ed6cead1096367e9a8c73f5ff554e8", null ],
    [ "TOWN_GROWTH_RATE_NONE", "d7/d3c/town_8h.html#af747166d122cd863cd72a348578738c3", null ],
    [ "TOWN_GROWTH_WINTER", "d7/d3c/town_8h.html#a0330eb282114055620f40d4eba196530", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d7/d3c/town_8h.js <==
var town_8h =
[
    [ "BuildingCounts", "dc/d60/structBuildingCounts.html", "dc/d60/structBuildingCounts" ],
    [ "TownCache", "db/d59/structTownCache.html", "db/d59/structTownCache" ],
    [ "Town", "d5/d2b/structTown.html", "d5/d2b/structTown" ],
    [ "TownPool", "d7/d3c/town_8h.html#a68179fc589018dd681c201465e81500f", null ],
    [ "TownActions", "d7/d3c/town_8h.html#a72b2e096f98a5a7ef720ef025f093e9f", [
      [ "TACT_NONE", "d7/d3c/town_8h.html#a72b2e096f98a5a7ef720ef025f093e9fad99b49a57498197befc36f4db8f86945", null ],
      [ "TACT_ADVERTISE_SMALL", "d7/d3c/town_8h.html#a72b2e096f98a5a7ef720ef025f093e9faff23739b2d068acce1a51ba397f6622d", null ],
      [ "TACT_ADVERTISE_MEDIUM", "d7/d3c/town_8h.html#a72b2e096f98a5a7ef720ef025f093e9fa20eab3954941c49fa89e346844fb359e", null ],
      [ "TACT_ADVERTISE_LARGE", "d7/d3c/town_8h.html#a72b2e096f98a5a7ef720ef025f093e9fafe2af793002e2bb9f47352824da2b3d6", null ],
      [ "TACT_ROAD_REBUILD", "d7/d3c/town_8h.html#a72b2e096f98a5a7ef720ef025f093e9fa1f7f29ec702d5622749aa0ad53b5e295", null ],
      [ "TACT_BUILD_STATUE", "d7/d3c/town_8h.html#a72b2e096f98a5a7ef720ef025f093e9fa0ba321c8f614ecc09a5e8be1e8f0ebe8", null ],
      [ "TACT_FUND_BUILDINGS", "d7/d3c/town_8h.html#a72b2e096f98a5a7ef720ef025f093e9faba3c259c45bbf8827520c049576ead8b", null ],
      [ "TACT_BUY_RIGHTS", "d7/d3c/town_8h.html#a72b2e096f98a5a7ef720ef025f093e9fa2b4e821fc7092f84195406d5d59a227b", null ],
      [ "TACT_BRIBE", "d7/d3c/town_8h.html#a72b2e096f98a5a7ef720ef025f093e9fa3d934b23e4970d085ad47873bbb2764e", null ],
      [ "TACT_COUNT", "d7/d3c/town_8h.html#a72b2e096f98a5a7ef720ef025f093e9fa591e8d8768b41649d6bb26330a2261fd", null ],
      [ "TACT_ADVERTISE", "d7/d3c/town_8h.html#a72b2e096f98a5a7ef720ef025f093e9fa4ad3cf8c16edcdcb4a50d2c9c052f6c2", null ],
      [ "TACT_CONSTRUCTION", "d7/d3c/town_8h.html#a72b2e096f98a5a7ef720ef025f093e9fa1505349147574404c149fd07dc46df42", null ],
      [ "TACT_FUNDS", "d7/d3c/town_8h.html#a72b2e096f98a5a7ef720ef025f093e9facfddb438ffb38e392c0916b7c1c4dfae", null ],
      [ "TACT_ALL", "d7/d3c/town_8h.html#a72b2e096f98a5a7ef720ef025f093e9fa856a9252cb1de2e44619f5a45acb83db", null ]
    ] ],
    [ "TownDirectoryInvalidateWindowData", "d7/d3c/town_8h.html#a3cb4961ecfc5790062f9579a115236cc", [
      [ "TDIWD_FORCE_REBUILD", "d7/d3c/town_8h.html#a3cb4961ecfc5790062f9579a115236cca2b18a97e49cea774d3610abf188671dc", null ],
      [ "TDIWD_POPULATION_CHANGE", "d7/d3c/town_8h.html#a3cb4961ecfc5790062f9579a115236cca941d15df0291d3f9e4b755f8cdc8b831", null ],
      [ "TDIWD_FORCE_RESORT", "d7/d3c/town_8h.html#a3cb4961ecfc5790062f9579a115236cca73d47032880ebdcd129ed686fb894126", null ]
    ] ],
    [ "TownFlags", "d7/d3c/town_8h.html#a3d1adcf1c18f19d00974fba3ba41c125", [
      [ "TOWN_IS_GROWING", "d7/d3c/town_8h.html#a3d1adcf1c18f19d00974fba3ba41c125a4cf8a495341d0d8a7011eac51a2fb978", null ],
      [ "TOWN_HAS_CHURCH", "d7/d3c/town_8h.html#a3d1adcf1c18f19d00974fba3ba41c125a1e3de1cbe2e682c8d0c4aa63a0c4980c", null ],
      [ "TOWN_HAS_STADIUM", "d7/d3c/town_8h.html#a3d1adcf1c18f19d00974fba3ba41c125a4b90abb9bbbe668d1b0e97ca3fa019f7", null ],
      [ "TOWN_CUSTOM_GROWTH", "d7/d3c/town_8h.html#a3d1adcf1c18f19d00974fba3ba41c125ad3f6b5cc75026c0848a0f63a14c24ee1", null ]
    ] ],
    [ "TownRatingCheckType", "d7/d3c/town_8h.html#a4c86370b4817abedcf0491b80262eb5a", [
      [ "ROAD_REMOVE", "d7/d3c/town_8h.html#a4c86370b4817abedcf0491b80262eb5aa1a4afb382e9f6142a316e3310957e7c3", null ],
      [ "TUNNELBRIDGE_REMOVE", "d7/d3c/town_8h.html#a4c86370b4817abedcf0491b80262eb5aaebb872165d784ea990c873a8f868412a", null ],
      [ "TOWN_RATING_CHECK_TYPE_COUNT", "d7/d3c/town_8h.html#a4c86370b4817abedcf0491b80262eb5aafa1361ad0ad1bd7300e75fec950aaf92", null ]
    ] ],
    [ "CalcClosestTownFromTile", "d7/d3c/town_8h.html#a9e7b91f9ad0689788a4ca95af39eb210", null ],
    [ "ChangeTownRating", "d7/d3c/town_8h.html#aa401b952a00674845ccb4273050928da", null ],
    [ "CheckforTownRating", "d7/d3c/town_8h.html#acebc77005f110c964d3d5850edb7a296", null ],
    [ "CheckIfAuthorityAllowsNewStation", "d7/d3c/town_8h.html#aca6c6d9e664f92c2c407015d2e2f7797", null ],
    [ "ClearAllTownCachedNames", "d7/d3c/town_8h.html#aa3a6e41c0b2566eb37d2cbb783be846d", null ],
    [ "ClearTownHouse", "d7/d3c/town_8h.html#a27b0cd4feaa3b85e5b9bc1ceea1eacc9", null ],
    [ "ClosestTownFromTile", "d7/d3c/town_8h.html#aefa41cb32a5c5faf518e67d065e7e0aa", null ],
    [ "ExpandTown", "d7/d3c/town_8h.html#adff01d611111448e7d7d2f2eaec194f4", null ],
    [ "FindFirstCargoWithTownEffect", "d7/d3c/town_8h.html#aab72028c5d4b66eb49342c7e2b7b7c20", null ],
    [ "GenerateTowns", "d7/d3c/town_8h.html#ac91d59f170b938ec1b4cbbf3b8618f64", null ],
    [ "GetHouseNorthPart", "d7/d3c/town_8h.html#a208081907f1ac4046976e0fc57541cee", null ],
    [ "GetMaskOfTownActions", "d7/d3c/town_8h.html#a18def58b8accdaf835f958d548f8e164", null ],
    [ "GetTownRadiusGroup", "d7/d3c/town_8h.html#a10f6e3691ee7cc2f6a363f25d5b88024", null ],
    [ "GetTownRoadType", "d7/d3c/town_8h.html#a613d921bd418fc0ae747e7b2b53d0bce", null ],
    [ "GetWorldPopulation", "d7/d3c/town_8h.html#a27638ea8500cdb01e0d227e41ec59276", null ],
    [ "MakeDefaultName", "d7/d3c/town_8h.html#af900090912159e59f37b1c5efc2db226", null ],
    [ "RebuildTownKdtree", "d7/d3c/town_8h.html#ac7872f3f397aba7db91bf2bc827e8985", null ],
    [ "ResetHouses", "d7/d3c/town_8h.html#a147c34083fcb9fb68acf342403e812c1", null ],
    [ "SetTownRatingTestMode", "d7/d3c/town_8h.html#ad64a5b99bb3a7b288704ab1b786ddf7e", null ],
    [ "ShowTownViewWindow", "d7/d3c/town_8h.html#a7fa05100148d062259fe641fdfbdd5a8", null ],
    [ "TownTicksToGameTicks", "d7/d3c/town_8h.html#a4b26e8253fd291e3a3636d26cdd8b51f", null ],
    [ "UpdateAllTownVirtCoords", "d7/d3c/town_8h.html#afccb9292782ea4d9a12573d4a45bdbea", null ],
    [ "UpdateTownMaxPass", "d7/d3c/town_8h.html#a7cd754f6784c6cb4338a139ef7acbdd2", null ],
    [ "UpdateTownRadius", "d7/d3c/town_8h.html#add12c33889bf9775a848384d3a9dd32d", null ],
    [ "_new_town_id", "d7/d3c/town_8h.html#a03764eb9bec65bdcd9a41de5d514323b", null ],
    [ "_town_action_costs", "d7/d3c/town_8h.html#a0f5db20740045b5f48bfaf0a3ca6c565", null ],
    [ "_town_pool", "d7/d3c/town_8h.html#a03bf9fd09ecb05692b990c7333e104d7", null ],
    [ "CUSTOM_TOWN_MAX_NUMBER", "d7/d3c/town_8h.html#a6e12dc158c20578e0b2a57344c8c90e4", null ],
    [ "CUSTOM_TOWN_NUMBER_DIFFICULTY", "d7/d3c/town_8h.html#aa1d17bb2c2d2e1cff4ce12def54e73d0", null ],
    [ "INVALID_TOWN", "d7/d3c/town_8h.html#ae581e6ec9bc5fd49cc42c1851a47ce9c", null ],
    [ "MAX_TOWN_GROWTH_TICKS", "d7/d3c/town_8h.html#a628187fb72c38bc95d4a95bb1e0676a4", null ],
    [ "TOWN_GROWTH_DESERT", "d7/d3c/town_8h.html#a39ed6cead1096367e9a8c73f5ff554e8", null ],
    [ "TOWN_GROWTH_RATE_NONE", "d7/d3c/town_8h.html#af747166d122cd863cd72a348578738c3", null ],
    [ "TOWN_GROWTH_WINTER", "d7/d3c/town_8h.html#a0330eb282114055620f40d4eba196530", null ]
];
